Crate draxl_rust

Crate draxl_rust 

Rust-profile support for Draxl.

The crate owns Rust-profile parsing, rendering, lowering, and import helpers so the generic surface crates can dispatch by lower language.

Re-exports

pub use import::import_source;
pub use import::ImportError;
pub use lower::lower_file;
pub use merge_context::TreeContext;
pub use merge_semantics::extract_semantic_changes;
pub use merge_semantics::SemanticChange;
pub use merge_semantics::SemanticOp;
pub use merge_semantics::SemanticOwner;
pub use merge_semantics::SemanticPatchNode;
pub use merge_semantics::SemanticRegion;
pub use merge_semantics::SemanticSlotOwner;
pub use merge_semantics::SemanticSlotRef;
pub use parse::parse_comment_fragment;
pub use parse::parse_doc_fragment;
pub use parse::parse_expr_fragment;
pub use parse::parse_field_fragment;
pub use parse::parse_file;
pub use parse::parse_item_fragment;
pub use parse::parse_match_arm_fragment;
pub use parse::parse_param_fragment;
pub use parse::parse_pattern_fragment;
pub use parse::parse_stmt_fragment;
pub use parse::parse_type_fragment;
pub use parse::parse_variant_fragment;
pub use parse::ParseError;
pub use render::print_file;

Modules

import
Importing ordinary Rust source into the Draxl AST.
lower
Lowering validated Draxl Rust-profile input to ordinary Rust source.
merge_context
merge_semantics
parse
patch_schema
render