pub enum ImportError {
RustParse(Error),
Unsupported(Error),
}Expand description
Import failure while converting ordinary Rust into Draxl.
Variants
RustParse(Error)
The Rust source could not be parsed by the import frontend.
Unsupported(Error)
The Rust source used syntax outside the currently supported import subset.