pub fn parse_comment_fragment(source: &str) -> Result<CommentNode, ParseError>Expand description
Parses a single line comment fragment for patch resolution.
pub fn parse_comment_fragment(source: &str) -> Result<CommentNode, ParseError>Parses a single line comment fragment for patch resolution.